View source: R/civic_explain.R
| civic_explain_local | R Documentation |
Explains why the model made a specific prediction for one or more individual observations. Uses DALEX break-down if available, falls back to coefficient contributions for GLM and LM models.
civic_explain_local(explainer, newdata, n_features = 10L)
explainer |
A civic_explainer from civic_explain(). |
newdata |
A data frame of observations to explain. |
n_features |
Integer. Maximum features to show. Default 10. |
A list of tibbles, one per row of newdata.
m <- civic_fit(Species ~ ., iris)
ex <- civic_explain(m)
civic_explain_local(ex, iris[1, ])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.