summary.civic_model: Summary of a civic_model

View source: R/civic_fit.R

summary.civic_modelR Documentation

Summary of a civic_model

Description

Summary of a civic_model

Usage

## S3 method for class 'civic_model'
summary(object, ...)

Arguments

object

A civic_model object.

...

Further arguments passed to or from other methods.

Value

Invisibly returns the summary of the underlying fitted model. Called for its side effect of printing a detailed model summary to the console.


civic.icarm documentation built on June 18, 2026, 1:06 a.m.