| summary.civic_model | R Documentation |
Summary of a civic_model
## S3 method for class 'civic_model'
summary(object, ...)
object |
A civic_model object. |
... |
Further arguments passed to or from other methods. |
Invisibly returns the summary of the underlying fitted model. Called for its side effect of printing a detailed model summary to the console.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.